@@ -1,8 +1,9 @@
 package DBIx::Custom::Basic;
-use base 'DBIx::Custom';
 
 use warnings;
 use strict;
+
+use base 'DBIx::Custom';
 use Encode qw/decode encode/;
 
 __PACKAGE__->add_filter(
@@ -19,7 +20,6 @@ __PACKAGE__->add_format(
     'ISO-8601_time'     => '%H:%M:%S',
 );
 
-# Methods
 sub utf8_filter_on {
     my $self = shift;
     
@@ -36,16 +36,20 @@ sub utf8_filter_on {
 
 DBIx::Custom::Basic - DBIx::Custom basic implementation
 
-=head1 See DBIx::Custom documentation
+=head1 SYNOPSYS
+
+    # New
+    my $dbi = DBIx::Custom::Basic->new(
+        data_source => "dbi:mysql:database=books",
+        user        => 'ken',
+        password    => '!LFKD%$&'
+    );
+
+=head1 METHODS
 
 This class is L<DBIx::Custom> subclass.
-
 You can use all methods of L<DBIx::Custom>
 
-Please see L<DBIx::Custom> documentation
-
-=head1 Methods
-
 =head2 utf8_filter_on
 
 Encode and decode utf8 filter on
@@ -57,7 +61,7 @@ This equel to
     $dbi->bind_filter($dbi->filters->{encode_utf8});
     $dbi->fetch_filter($dbi->filters->{decode_utf8});
 
-=head1 Available filters
+=head1 FILTERS
 
 =head2 encode_utf8
 
@@ -79,7 +83,7 @@ This filter is generally used as fetch filter
 
     $dbi->fetch_filter($dbi->filters->{decode_utf8});
 
-=head2 Available formats
+=head1 DATE FORMATS
     
 strptime formats is available
     
@@ -95,19 +99,4 @@ You get format as the following
 
     my $format = $dbi->formats->{$format_name};
 
-=head1 AUTHOR
-
-Yuki Kimoto, C<< <kimoto.yuki at gmail.com> >>
-
-Github L<http://github.com/yuki-kimoto>
-
-I develope this module L<http://github.com/yuki-kimoto/DBIx-Custom>
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2009 Yuki Kimoto, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
 =cut
