@@ -1,9 +1,10 @@
 package DBIx::Custom::Query;
-use base 'Object::Simple';
 
 use strict;
 use warnings;
 
+use base 'Object::Simple';
+
 __PACKAGE__->attr([qw/sql key_infos bind_filter fetch_filter sth/]);
 __PACKAGE__->attr(_no_bind_filters => sub { {} });
 __PACKAGE__->attr(no_fetch_filters => sub { [] });
@@ -11,6 +12,7 @@ __PACKAGE__->attr(no_fetch_filters => sub { [] });
 sub new {
     my $self = shift->SUPER::new(@_);
     
+    # Initialize attributes
     $self->no_bind_filters($self->{no_bind_filters})
       if $self->{no_bind_filters};
     
@@ -21,10 +23,11 @@ sub no_bind_filters {
     my $self = shift;
     
     if (@_) {
+        # Set
         $self->{no_bind_filters} = $_[0];
         
+        # Cached
         my %no_bind_filters = map { $_ => 1 } @{$self->{no_bind_filters}};
-        
         $self->_no_bind_filters(\%no_bind_filters);
         
         return $self;
@@ -33,6 +36,8 @@ sub no_bind_filters {
     return $self->{no_bind_filters};
 }
 
+1;
+
 =head1 NAME
 
 DBIx::Custom::Query - DBIx::Custom query
@@ -52,76 +57,64 @@ DBIx::Custom::Query - DBIx::Custom query
     $query->fetch_filter($dbi->filters->{default_fetch_filter});
     $query->no_fetch_filters('title', 'author');
 
-=head1 Accessors
+=head1 ATTRIBUTES
 
 =head2 sth
 
-Set and get statement handle
+Statement handle
 
     $query = $query->sth($sth);
     $sth   = $query->sth;
 
 =head2 sql
 
-Set and get SQL
+SQL
 
     $query = $query->sql($sql);
     $sql   = $query->sql;
 
 =head2 bind_filter
 
-Set and get bind filter
+Filter excuted when value is bind
 
     $query       = $query->bind_filter($bind_filter);
     $bind_filter = $query->bind_filter;
 
 =head2 no_bind_filters
 
-Set and get keys of no filtering
+Key list which dose not have to bind filtering
 
     $query           = $query->no_bind_filters($no_filters);
     $no_bind_filters = $query->no_bind_filters;
 
 =head2 fetch_filter
 
-Set and get fetch filter
+Filter excuted when data is fetched
 
     $query        = $query->fetch_filter($fetch_filter);
     $fetch_filter = $query->fetch_filter;
 
 =head2 no_fetch_filters
 
-Set and get keys of no filtering
+Key list which dose not have to fetch filtering
 
     $query            = $query->no_fetch_filters($no_filters);
     $no_fetch_filters = $query->no_fetch_filters;
 
 =head2 key_infos
 
-Set and get key informations
+Key informations
 
     $query     = $query->key_infos($key_infos);
     $key_infos = $query->key_infos;
 
-=head1 Methods
+=head1 METHODS
+
+This class is L<Object::Simple> subclass.
+You can use all methods of L<Object::Simple>
 
 =head2 new
 
     my $query = DBIx::Custom::Query->new;
-    
-=head1 AUTHOR
-
-Yuki Kimoto, C<< <kimoto.yuki at gmail.com> >>
-
-Github L<http://github.com/yuki-kimoto>
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2009 Yuki Kimoto, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
 
 =cut
-
-1;
\ No newline at end of file
